==> rendition-11.7.1.tgz: package/dist_esm5/components/Filters/Summary.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import Button from '../Button';
import { Box, Flex } from '../Grid';
import Input from '../Input';
import Modal from '../Modal';
import Select from '../Select';
import Txt from '../Txt';
import FilterDescription from './FilterDescription';
var FilterSummary = (function (_super) {
    tslib_1.__extends(FilterSummary, _super);
    function FilterSummary(props) {
        var _this = _super.call(this, props) || this;
        _this.save = function (event) {
            if (event) {
                event.preventDefault();
            }
            var _a = _this.state, name = _a.name, scope = _a.scope;
            if (!name) {
                return;
            }
            _this.props.saveView(name, scope);
            _this.setState({
                name: '',
                showForm: false,
                id: '',
            });
        };
        _this.state = {
            name: '',
            showForm: false,
            id: '',
            scope: _this.props.scopes ? _this.props.scopes[0].slug : null,
        };
        return _this;
    }
    FilterSummary.prototype.handleChange = function (e) {
        var name = e.target.value;
        this.setState({ name: name });
    };
    FilterSummary.prototype.render = function () {
        var _this = this;
        var scopes = this.props.scopes;
        return (React.createElement(Box, { p: 3, mt: 3, width: "100%", bg: "quartenary.light" },
            this.state.showForm && (React.createElement(Modal, { title: "Save current view", cancel: function () { return _this.setState({ showForm: false }); }, done: this.save, action: "Save" },
                React.createElement("form", { onSubmit: this.save },
                    !!scopes && scopes.length > 1 && (React.createElement(Flex, { mb: 4, alignItems: "center" },
                        React.createElement(Txt, { width: 90 }, "Visible to:"),
                        React.createElement(Select, { ml: 2, width: "auto", options: scopes, valueKey: "slug", labelKey: "name", value: scopes.find(function (x) { return x.slug === _this.state.scope; }), onChange: function (_a) {
                                var option = _a.option;
                                return _this.setState({
                                    scope: option.slug,
                                });
                            } }))),
                    React.createElement(Input, { width: "100%", value: this.state.name, placeholder: "Enter a name for the view", onChange: function (e) {
                            return _this.handleChange(e);
                        }, autoFocus: true })))),
            React.createElement(Flex, { mb: 2 },
                React.createElement(Txt, { fontSize: 13, color: this.props.dark ? '#fff' : 'secondary.main' },
                    "Filters (",
                    this.props.filters.length,
                    ")"),
                React.createElement(Button, { primary: true, plain: true, fontSize: 13, ml: 3, onClick: function () { return _this.setState({ showForm: !_this.state.showForm }); } }, "Save view")),
            React.createElement(Flex, { flexWrap: "wrap" }, this.props.filters.map(function (filter, index) {
                return (React.createElement(Box, { mr: 3, mt: 2, key: index },
                    React.createElement(FilterDescription, { dark: _this.props.dark, filter: filter, edit: function () { return _this.props.edit(filter); }, delete: function () { return _this.props.delete(filter); } })));
            }))));
    };
    return FilterSummary;
}(React.Component));
export default FilterSummary;

==> rendition-11.10.0.tgz: package/dist_esm5/components/Filters/Summary.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaChartPie from 'react-icons/lib/fa/pie-chart';
import Button from '../Button';
import { Box, Flex } from '../Grid';
import Input from '../Input';
import Modal from '../Modal';
import Select from '../Select';
import Txt from '../Txt';
import FilterDescription from './FilterDescription';
var FilterSummary = (function (_super) {
    tslib_1.__extends(FilterSummary, _super);
    function FilterSummary(props) {
        var _this = _super.call(this, props) || this;
        _this.save = function (event) {
            if (event) {
                event.preventDefault();
            }
            var _a = _this.state, name = _a.name, scope = _a.scope;
            if (!name) {
                return;
            }
            _this.props.saveView(name, scope);
            _this.setState({
                name: '',
                showForm: false,
                id: '',
            });
        };
        _this.state = {
            name: '',
            showForm: false,
            id: '',
            scope: _this.props.scopes ? _this.props.scopes[0].slug : null,
        };
        return _this;
    }
    FilterSummary.prototype.handleChange = function (e) {
        var name = e.target.value;
        this.setState({ name: name });
    };
    FilterSummary.prototype.render = function () {
        var _this = this;
        var scopes = this.props.scopes;
        return (React.createElement(Box, { p: 3, mt: 3, width: "100%", bg: "quartenary.light" },
            this.state.showForm && (React.createElement(Modal, { title: "Save current view", cancel: function () { return _this.setState({ showForm: false }); }, done: this.save, action: "Save" },
                React.createElement("form", { onSubmit: this.save },
                    !!scopes && scopes.length > 1 && (React.createElement(Flex, { mb: 4, alignItems: "center" },
                        React.createElement(Txt, { width: 90 }, "Visible to:"),
                        React.createElement(Select, { ml: 2, width: "auto", options: scopes, valueKey: "slug", labelKey: "name", value: scopes.find(function (x) { return x.slug === _this.state.scope; }), onChange: function (_a) {
                                var option = _a.option;
                                return _this.setState({
                                    scope: option.slug,
                                });
                            } }))),
                    React.createElement(Input, { width: "100%", value: this.state.name, placeholder: "Enter a name for the view", onChange: function (e) {
                            return _this.handleChange(e);
                        }, autoFocus: true })))),
            React.createElement(Flex, { mb: 2, justifyContent: "space-between" },
                React.createElement(Flex, null,
                    React.createElement(Txt, { mr: 2, color: this.props.dark ? '#fff' : 'secondary.main' },
                        React.createElement(Txt.span, { bold: true }, "Filters"),
                        " (",
                        this.props.filters.length,
                        ")"),
                    React.createElement(Button, { plain: true, primary: true, onClick: this.props.clearAllFilters }, "Clear all")),
                React.createElement(Button, { primary: true, plain: true, onClick: function () { return _this.setState({ showForm: !_this.state.showForm }); }, icon: React.createElement(FaChartPie, null) }, "Save as view")),
            React.createElement(Flex, { flexWrap: "wrap" }, this.props.filters.map(function (filter, index) {
                return (React.createElement(Box, { mr: 3, mt: 2, key: index },
                    React.createElement(FilterDescription, { dark: _this.props.dark, filter: filter, edit: function () { return _this.props.edit(filter); }, delete: function () { return _this.props.delete(filter); } })));
            }))));
    };
    return FilterSummary;
}(React.Component));
export default FilterSummary;
